@@ -140,7 +140,7 @@
 **  loadave  current load average
 */
 
-static char ident[] = "@(#) fujitsu/$RCSfile$ $Revision: 3151 $";
+static char ident[] = "@(#) fujitsu/$RCSfile$ $Revision: 3230 $";
 
 #ifndef TRUE
 #define FALSE 0
@@ -155,9 +155,9 @@ static char ident[] = "@(#) fujitsu/$RCSfile$ $Revision: 3151 $";
 ** external functions and data
 */
 
-extern struct config  *search A_((struct config *, char *));
+extern struct config  *search(struct config *, char *);
 
-extern struct rm_attribute *momgetattr A_((char *));
+extern struct rm_attribute *momgetattr(char *);
 extern int   rm_errno;
 extern unsigned int reqnum;
 extern double cputfactor;
@@ -171,15 +171,15 @@ extern  int     ignmem;
 /*
 ** local functions and data
 */
-static char *resi  A_((struct rm_attribute *attrib));
-static char *physmem A_((struct rm_attribute *attrib));
-static char *availmem A_((struct rm_attribute *attrib));
-static char *totmem  A_((struct rm_attribute *attrib));
-static char *ncpus  A_((struct rm_attribute *attrib));
-static char *walltime A_((struct rm_attribute *attrib));
+static char *resi     (struct rm_attribute *attrib);
+static char *physmem  (struct rm_attribute *attrib);
+static char *availmem (struct rm_attribute *attrib);
+static char *totmem   (struct rm_attribute *attrib);
+static char *ncpus    (struct rm_attribute *attrib);
+static char *walltime (struct rm_attribute *attrib);
 
-extern char *loadave A_((struct rm_attribute *attrib));
-extern char *nullproc A_((struct rm_attribute *attrib));
+extern char *loadave  (struct rm_attribute *attrib);
+extern char *nullproc (struct rm_attribute *attrib);
 
 char  procfs[] = "/proc";
 char  procfmts[] = "/proc/%s";
