@@ -138,12 +138,6 @@ extern int TTmpDirName(job*, char *);
 
 #endif /* HAVE_WORDEXP */
 
-#ifdef NVIDIA_GPUS
-int setgpumode(char *, int);
-int resetgpuecc(char *, int, int);
-extern void mom_server_all_update_gpustat(void);
-#endif /* NVIDIA_GPUS */
-
 /* External Global Data Items */
 
 extern unsigned int alarm_time;
@@ -159,11 +153,8 @@ extern char            *msg_jobmod;
 extern char            *msg_manager;
 extern time_t  time_now;
 extern int  resc_access_perm; /* see encode_resc() */
+extern int  multi_mom;
 extern int spoolasfinalname;
-#ifdef NVIDIA_GPUS
-extern int  use_nvidia_gpu;
-#endif /* NVIDIA_GPUS */
-
 /* in attr_fn_resc.c */
 
 extern char             MOMUNameMissing[];
@@ -190,7 +181,6 @@ extern int  LOGLEVEL;
 
 extern int im_compose(int, char *, char *, int, tm_event_t, tm_task_id);
 extern int mom_open_socket_to_jobs_server(job *, char *, void (*)(int));
-extern int TMOMJobGetStartInfo(job *, pjobexec_t **) ;
 
 /* prototypes */
 
@@ -219,7 +209,7 @@ char *get_job_envvar(
   pc = arst_string(
 
          variable,
-         &pjob->ji_wattr[(int)JOB_ATR_variables]);
+         &pjob->ji_wattr[JOB_ATR_variables]);
 
   if (pc != NULL)
     {
@@ -291,7 +281,7 @@ static pid_t fork_to_user(
     }
   else
     {
-    if ((pwdp = getpwnam_ext(preq->rq_ind.rq_cpyfile.rq_user)) == NULL)
+    if ((pwdp = getpwnam(preq->rq_ind.rq_cpyfile.rq_user)) == NULL)
       {
       if (MOMUNameMissing[0] == '\0')
         strncpy(MOMUNameMissing, preq->rq_ind.rq_cpyfile.rq_user, 64);
@@ -456,9 +446,9 @@ static pid_t fork_to_user(
     {
     /* set account id */
 
-    if (pjob->ji_wattr[(int)JOB_ATR_account].at_flags & ATR_VFLAG_SET)
+    if (pjob->ji_wattr[JOB_ATR_account].at_flags & ATR_VFLAG_SET)
       {
-      acctid(0, nam2acid(pjob->ji_wattr[(int)JOB_ATR_account].at_val.at_str));
+      acctid(0, nam2acid(pjob->ji_wattr[JOB_ATR_account].at_val.at_str));
       }
     }
 
@@ -1117,7 +1107,6 @@ void req_deletejob(
 
   {
   job *pjob;
-  pjobexec_t *TJE = NULL;
 
   pjob = find_job(preq->rq_ind.rq_delete.rq_objname);
 
@@ -1132,19 +1121,6 @@ void req_deletejob(
         "deleting job");
       }
 
-    /*
-     * We need to clear out the TJE starter slot if this job is in it.  This
-     * can occur if we qdel the job while the prologue is running.  If we
-     * don't remove ourself here then the TJE slot may remain with data that is
-     * no longer valid, yet we will reuse the slot since it only matches on the
-     * address of the pjob not on a jobid.  This can lead to unexpected crashes.
-     */
-
-    if (TMOMJobGetStartInfo(pjob, &TJE) == SUCCESS)
-      {
-      memset(TJE, 0, sizeof(pjobexec_t));
-      }
-
     /* assume success? */
 
     mom_deljob(pjob);
@@ -1188,11 +1164,11 @@ void req_holdjob(
     {
     /* propagate servers hold state to job */
 
-    clear_attr(&tmph, &job_attr_def[(int)JOB_ATR_hold]);
+    clear_attr(&tmph, &job_attr_def[JOB_ATR_hold]);
 
     if ((pal = (svrattrl *)GET_NEXT(preq->rq_ind.rq_hold.rq_orig.rq_attr)) != NULL)
       {
-      job_attr_def[(int)JOB_ATR_hold].at_decode(
+      job_attr_def[JOB_ATR_hold].at_decode(
         &tmph,
         pal->al_name,
         NULL,
@@ -1244,118 +1220,6 @@ void req_checkpointjob(
 
 
 
-void req_gpuctrl(
-
-  struct batch_request *preq)  /* I */
-
-  {
-  char   *id = "req_gpuctrl";
-
-  char *mom_node;
-  char *gpuid;
-  int   gpumode = -1;
-  int   reset_perm = -1;
-  int   reset_vol = -1;
-#ifdef NVIDIA_GPUS
-  int   rc = -1;
-#endif  /* NVIDIA_GPUS */
-
-  gpuid = preq->rq_ind.rq_gpuctrl.rq_gpuid;
-  gpumode = preq->rq_ind.rq_gpuctrl.rq_gpumode;
-  mom_node = preq->rq_ind.rq_gpuctrl.rq_momnode;
-  reset_perm = preq->rq_ind.rq_gpuctrl.rq_reset_perm;
-  reset_vol = preq->rq_ind.rq_gpuctrl.rq_reset_vol;
-
-#ifdef NVIDIA_GPUS
-  if (LOGLEVEL >= 7)
-    {
-    sprintf(
-      log_buffer,
-      "GPU control request for node %s gpuid %s mode %d reset_perm %d reset_vol %d",
-      mom_node,
-      gpuid,
-      gpumode,
-      reset_perm,
-      reset_vol);
-    log_ext(-1, id, log_buffer, LOG_INFO);
-    }
-
-  if (!use_nvidia_gpu)
-    {
-    sprintf(
-      log_buffer,
-      "GPU control requests not active: node %s gpuid %s mode %d reset_perm %d reset_vol %d",
-      mom_node,
-      gpuid,
-      gpumode,
-      reset_perm,
-      reset_vol);
-
-    if (LOGLEVEL >= 3)
-      {
-        log_ext(-1, id, log_buffer, LOG_INFO);
-      }
-
-    req_reject(PBSE_NOSUP, 0, preq, NULL, NULL);
-    return;
-    }
-
-    /* assume success? */
-
-  if (gpumode != -1)
-    {
-    rc = setgpumode(gpuid, gpumode);
-    }
-  else if ((reset_perm != -1) || (reset_vol != -1))
-    {
-    rc = resetgpuecc(gpuid, reset_perm, reset_vol);
-    }
-
-  if (rc)
-    {
-    reply_ack(preq);
-
-    /*
-     * if we were successful changing the mode then we need to update the gpu
-     * statuses
-     */
-
-    if (gpumode != -1)
-      {
-      mom_server_all_update_gpustat();
-      }
-    }
-  else
-    {
-    req_reject(PBSE_RMSYSTEM, 0, preq, mom_host, "failed to set gpu status");
-    }
-#else
-
-  sprintf(
-    log_buffer,
-    "GPU control requests not supported: node %s gpuid %s mode %d reset_perm %d reset_vol %d",
-    mom_node,
-    gpuid,
-    gpumode,
-    reset_perm,
-    reset_vol);
-
-  if (LOGLEVEL >= 3)
-    {
-      log_ext(-1, id, log_buffer, LOG_INFO);
-    }
-
-  req_reject(PBSE_NOSUP, 0, preq, NULL, NULL);
-
-#endif  /* NVIDIA_GPUS */
-
-  return;
-  }  /* END req_deletejob() */
-
-
-
-
-
 /*
  *  Write text into a job's output file,
  *  Return a PBS error code.
@@ -1563,13 +1427,10 @@ const char *TJobAttr[] =
   "job_type",
   "inter_cmd",
   "proxy_user",
+  "exclusive_access",
 #ifdef USEJOBCREATE
   "pagg_id",
 #endif /* USEJOBCREATE */
-  "job_id",
-#ifdef NVIDIA_GPUS
-  "gpu_flags",
-#endif  /* NVIDIA_GPUS */
   NULL
   };
 
@@ -1589,11 +1450,12 @@ void req_modifyjob(
   {
   int   bad = 0;
   int   i;
-  attribute  newattr[(int)JOB_ATR_LAST];
+  attribute  newattr[JOB_ATR_LAST];
   attribute *pattr;
   job  *pjob;
   svrattrl *plist;
   int   rc;
+  unsigned int momport = 0;
 
   char tmpLine[1024];
 
@@ -1775,7 +1637,12 @@ void req_modifyjob(
     return;
     }
 
-  job_save(pjob, SAVEJOB_FULL);
+  if (multi_mom)
+    {
+    momport = pbs_rm_port;
+    }
+  
+  job_save(pjob, SAVEJOB_FULL, momport);
 
   sprintf(log_buffer, msg_manager,
           msg_jobmod,
@@ -1925,7 +1792,7 @@ int sigalltasks_sisters(
   eventent *ep;
   int i;
 
-  cookie = pjob->ji_wattr[(int)JOB_ATR_Cookie].at_val.at_str;
+  cookie = pjob->ji_wattr[JOB_ATR_Cookie].at_val.at_str;
 
   for (i = 0;i < pjob->ji_numnodes;i++)
     {
@@ -1938,13 +1805,13 @@ int sigalltasks_sisters(
     DBPRT(("%s: sending sig%d to all tasks on sister %s\n", id, signum, np->hn_host));
 
     if (np->hn_stream == -1)
-      np->hn_stream = rpp_open(np->hn_host, pbs_rm_port, NULL);
+      np->hn_stream = rpp_open(np->hn_host, np->hn_port, NULL);
 
     ep = event_alloc(IM_SIGNAL_TASK, np, TM_NULL_EVENT, TM_NULL_TASK);
 
     if (np->hn_stream == -1)
       {
-      np->hn_stream = rpp_open(np->hn_host, pbs_rm_port, NULL);
+      np->hn_stream = rpp_open(np->hn_host, np->hn_port, NULL);
       }
 
     ret = im_compose(np->hn_stream, pjob->ji_qs.ji_jobid, cookie, IM_SIGNAL_TASK, ep->ee_event, TM_NULL_TASK);
@@ -2215,6 +2082,7 @@ void req_signaljob(
   int             sig;
   int             numprocs=0;
   char           *sname;
+  unsigned int   momport = 0;
 
   struct sig_tbl *psigt;
 
@@ -2243,14 +2111,6 @@ void req_signaljob(
       log_buffer);
     }
 
-  if (preq->rq_extend != NULL)
-    {
-    if (!strcasecmp("rerun", preq->rq_extend))
-      {
-      pjob->ji_job_is_being_rerun = TRUE;
-      }
-    }
-
   if (!strcasecmp(sname, SIG_SUSPEND))
     {
     if (pjob->ji_qs.ji_substate != JOB_SUBSTATE_RUNNING)
@@ -2356,7 +2216,12 @@ void req_signaljob(
 
     pjob->ji_qs.ji_substate = JOB_SUBSTATE_EXITING;
 
-    job_save(pjob, SAVEJOB_QUICK);
+    if (multi_mom)
+      {
+      momport = pbs_rm_port;
+      }
+    
+    job_save(pjob, SAVEJOB_QUICK, momport);
 
     exiting_tasks = 1;
     }
@@ -2887,7 +2752,6 @@ static int del_files(
      */
 
 /*    if (del_dir) */
-    if (pair->fp_flag == JOBCKPFILE)
       {
       char *ptr;
       ptr = strrchr(path,'/');
@@ -2957,7 +2821,6 @@ void req_rerunjob(
   job  *pjob;
   int        sock;
   int   rc;
-  int   retrycnt = 0;
 
   pjob = find_job(preq->rq_ind.rq_rerun);
 
@@ -2997,17 +2860,10 @@ void req_rerunjob(
    * This is acceptable because we are a child process, not pbs_mom.
    */
 
-retry:
   sock = mom_open_socket_to_jobs_server(pjob, id, NULL);
 
   if (sock < 0)
     {
-    retrycnt++;
-    if (retrycnt < 10)
-      {
-      sleep(1);
-      goto retry;
-      }
     /* FAILURE */
 
     req_reject(PBSE_NOSERVER, 0, preq, NULL, NULL);
@@ -4039,7 +3895,7 @@ error:
         }
       else if (dir == CKPT_DIR_OUT)
         {
-        /*
+        /* 
          * we need to clean up the job checkpoint file
          * the job directory gets deleted when job is done
          */
