@@ -130,6 +130,14 @@ extern int h_errno;
 #endif
 extern time_t  time_now;
 
+typedef struct _node_info_
+  {
+  char     *nodename;
+  svrattrl *plist;
+  int      perms;
+  tlist_head atrlist;
+  }node_info;
+
 
 /* Global Data */
 
@@ -662,6 +670,8 @@ int status_nodeattrib(
       continue;
     else if (!strcmp((padef + i)->at_name, ATTR_NODE_numa_str))
       continue;
+    else if (!strcmp((padef + i)->at_name, ATTR_NODE_gpus_str))
+      continue;
     else if (!strcmp((padef + i)->at_name, ATTR_NODE_gpus))
       {
       atemp[i].at_val.at_long  = pnode->nd_ngpus;
@@ -1332,6 +1342,29 @@ int update_nodes_file(void)
         np->numa_str);
       }
 
+    /* write out the ports if needed */
+    if (np->nd_mom_port != PBS_MOM_SERVICE_PORT)
+      {
+      fprintf(nin, " %s=%d",
+        ATTR_NODE_mom_port,
+        np->nd_mom_port);
+      }
+    
+    if (np->nd_mom_rm_port != PBS_MANAGER_SERVICE_PORT)
+      {
+      fprintf(nin, " %s=%d",
+        ATTR_NODE_mom_rm_port,
+        np->nd_mom_rm_port);
+      }
+
+    if ((np->gpu_str != NULL) &&
+        (np->gpu_str[0] != '\0'))
+      {
+      fprintf(nin, " %s=%s",
+        ATTR_NODE_gpus_str,
+        np->gpu_str);
+      }
+
     /* write out properties */
 
     for (j = 0;j < np->nd_nprops - 1;++j)
@@ -1615,6 +1648,36 @@ int copy_properties(
 
 
 
+/*
+ * accepts a string of numbers separated by commas. it places the 
+ * number in val and advances the string to the next number past the comma
+ */
+
+int read_val_and_advance(
+
+  int   *val,
+  char **str)
+
+  {
+  char *comma;
+
+  if ((*str == NULL) ||
+      (val == NULL))
+    return(-1);
+
+  *val = atoi(*str);
+
+  comma = strchr(*str,',');
+
+  if (comma != NULL)
+    *str += comma - *str + 1;
+
+  return(PBSE_NONE);
+  } /* END read_val_and_advance() */
+
+
+
+
 
 /* creates the private numa nodes on this node 
  *
@@ -1633,9 +1696,10 @@ int setup_numa_nodes(
   struct pbsnode *pn;
   char            pname[MAX_LINE];
   char           *np_ptr = NULL;
+  char           *gp_ptr = NULL;
   char           *allocd_name;
   int             np;
-  char           *delim = ",";
+  int             gpus;
 
   char           *id = "setup_numa_nodes";
 
@@ -1652,13 +1716,20 @@ int setup_numa_nodes(
   /* determine the number of cores per node */
   if (pnode->numa_str != NULL)
     {
-    np_ptr = strtok(pnode->numa_str,delim);
-    np = atoi(np_ptr);
+    np_ptr = pnode->numa_str;
+    read_val_and_advance(&np,&np_ptr);
     }
   else
-    {
     np = pnode->nd_nsn / pnode->num_numa_nodes;
+
+  /* determine the number of gpus per node */
+  if (pnode->gpu_str != NULL)
+    {
+    gp_ptr = pnode->gpu_str;
+    read_val_and_advance(&gpus,&gp_ptr);
     }
+  else
+    gpus = pnode->nd_ngpus / pnode->num_numa_nodes;
 
   for (i = 0; i < pnode->num_numa_nodes; i++)
     {
@@ -1696,13 +1767,27 @@ int setup_numa_nodes(
         }
       }
 
-    /* set the number of processors */
+    /* update the np string pointer */
     if (np_ptr != NULL)
+      read_val_and_advance(&np,&np_ptr);
+      
+
+    /* create the gpu subnodes for this node */
+    for (j = 0; j < gpus; j++)
       {
-      np_ptr = strtok(NULL,delim);
-      np = atoi(np_ptr);
+      if (create_a_gpusubnode(pn) != PBSE_NONE)
+        {
+        /* ERROR */
+        pn->nd_state = INUSE_DELETED;
+
+        return(PBSE_SYSTEM);
+        }
       }
 
+    /* update the gpu string pointer */
+    if (gp_ptr != NULL)
+      read_val_and_advance(&gpus,&gp_ptr);
+
     copy_properties(pn,pnode);
 
     /* add the node to the private tree */
@@ -1730,7 +1815,41 @@ int setup_numa_nodes(
   } /* END setup_numa_nodes() */
 
 
+/* recheck_for_node :
+ * This function is called whenever an entry in the nodes file does
+ * not resolve on server initialization. This function is called 
+ * periodically to see if the node is now resolvable and if so 
+ * add it to the list of available MOM nodes. */ 
+void recheck_for_node( struct work_task *ptask)
+  {
+  node_info *host_info;
+  int rc;
+  int bad;
 
+  host_info = ptask->wt_parm1;
+  if(host_info == NULL)
+    {
+    return;
+    }
+
+
+  rc = create_pbs_node( host_info->nodename, host_info->plist, host_info->perms, &bad);
+  if(rc)
+    {
+    /* we created a new host_info in create_pbs_node. We
+       need to free this one */
+    free_attrlist(&host_info->atrlist);
+    if(host_info->nodename)
+      {
+      free(host_info->nodename);
+      }
+
+    free(host_info);
+    }
+
+  return;
+
+  }
 
 
 /*
@@ -1755,14 +1874,68 @@ int create_pbs_node(
   u_long          *pul;  /* 0 terminated host adrs array*/
   int              rc;
   int              iht;
+  node_info        *host_info;
   int              i;
   int              reused_entry = 0;
   u_long           addr;
 
   if ((rc = process_host_name_part(objname, &pul, &pname, &ntype)) != 0)
     {
+    svrattrl *pal, *pattrl;
+
     log_err(-1, "process_host_name_part", log_buffer);
 
+    /* the host name in the nodes file did not resolve.
+       We will set up a process to check periodically
+       to see if the node will resolve later */
+
+    host_info = (node_info *)calloc(1, sizeof(node_info));
+    if(host_info == NULL)
+      {
+      log_err(-1, "create_pbs_node calloc failed", log_buffer);
+      return(PBSE_SYSTEM);
+      }
+
+    CLEAR_HEAD(host_info->atrlist);
+
+    /* allocate and copy the objname plist and perms */
+    host_info->perms = perms;
+    pal = plist;
+
+    while(pal != NULL)
+      {
+      pattrl = attrlist_create(pal->al_atopl.name, 0, strlen(pal->al_atopl.value) + 1);
+      if(pattrl == NULL)
+        {
+        log_err(-1, "cannot create node attribute", log_buffer);
+        return(PBSE_SYSTEM);                    
+        }
+
+      strcpy(pattrl->al_value, pal->al_atopl.value);
+      pattrl->al_flags = SET;
+
+      append_link(&host_info->atrlist, &pattrl->al_link, pattrl);
+      pal = GET_NEXT(pal->al_link);
+      }
+
+    pattrl = GET_NEXT(host_info->atrlist);
+    host_info->plist = pattrl;
+
+    if(objname != NULL)
+      {
+      host_info->nodename = (char *)calloc(1, strlen(objname)+1);
+      if(host_info->nodename == NULL)
+        {
+        free(host_info);
+        log_err(-1, "create_pbs_node calloc failed", log_buffer);
+        return(PBSE_SYSTEM);
+        }
+      strcpy(host_info->nodename, objname);
+      }
+
+
+    set_task(WORK_Timed, time_now + 30 /*PBS_LOG_CHECK_RATE  five minutes */, recheck_for_node, host_info);
+
     return(rc);
     }
 
@@ -1990,6 +2163,7 @@ static char *parse_node_token(
 
   char *start, /* if null, restart where left off */
   int   cok, /* flag - non-zero if colon ":" allowed in token */
+  int   comma, /* flag - non-zero if comma ',' allowed in token */
   int  *err, /* RETURN: non-zero if error */
   char *term) /* RETURN: character terminating token */
 
@@ -2025,6 +2199,9 @@ static char *parse_node_token(
     if (cok && (*pt == ':'))
       continue;
 
+    if (comma && (*pt == ','))
+      continue;
+
     if (!cok && (*pt == '='))
       break;
 
@@ -2033,7 +2210,10 @@ static char *parse_node_token(
 
   *term = *pt;
 
-  *pt++ = '\0';
+  if(*pt != '\0')
+    {
+    *pt++ = '\0';
+    }
 
   return(ts);
   }  /* END parse_node_token() */
@@ -2129,7 +2309,7 @@ int setup_nodes(void)
 
     propstr[0] = '\0';
 
-    token = parse_node_token(line, 1, &err, &xchar);
+    token = parse_node_token(line, 1, 0, &err, &xchar);
 
     if (token == NULL)
       continue; /* blank line */
@@ -2159,7 +2339,7 @@ int setup_nodes(void)
 
     while (1)
       {
-      token = parse_node_token(NULL, 0, &err, &xchar);
+      token = parse_node_token(NULL, 0, 0, &err, &xchar);
 
       if (err != 0)
         goto errtoken1;
@@ -2171,7 +2351,7 @@ int setup_nodes(void)
         {
         /* have new style attribute, keyword=value */
 
-        val = parse_node_token(NULL, 0, &err, &xchar);
+        val = parse_node_token(NULL, 0, 1, &err, &xchar);
 
         if ((val == NULL) || (err != 0) || (xchar == '='))
           goto errtoken1;
@@ -2787,7 +2967,63 @@ int numa_str_action(
     }
 
   return(0);
-  } /* END numa_str_action */
+  } /* END numa_str_action() */
+
+
+
+
+int gpu_str_action(
+
+  attribute *new,
+  void      *pnode,
+  int        actmode)
+
+  {
+  struct pbsnode *np = (struct pbsnode *)pnode;
+  int             len;
+
+  switch (actmode)
+    {
+    case ATR_ACTION_NEW:
+
+      if (np->gpu_str != NULL)
+        {
+        len = strlen(np->gpu_str) + 1;
+        new->at_val.at_str = (char *)malloc(len * sizeof(char));
+
+        if (new->at_val.at_str == NULL)
+          return(PBSE_SYSTEM);
+
+        strcpy(new->at_val.at_str,np->gpu_str);
+        }
+      else
+        new->at_val.at_str = NULL;
+
+      break;
+
+    case ATR_ACTION_ALTER:
+
+      if (new->at_val.at_str != NULL)
+        {
+        len = strlen(new->at_val.at_str) + 1;
+        np->gpu_str = (char *)malloc(len * sizeof(char));
+
+        if (np->gpu_str == NULL)
+          return(PBSE_SYSTEM);
+
+        strcpy(np->gpu_str,new->at_val.at_str);
+        }
+      else
+        np->gpu_str = NULL;
+
+      break;
+
+    default:
+      return(PBSE_INTERNAL);
+    }
+
+  return(PBSE_NONE);
+  } /* END gpu_str_action() */
 
 
 
