@@ -126,6 +126,7 @@ extern char *msg_job_end_sig;
 extern char *msg_job_end_stat;
 extern char *msg_momnoexec1;
 extern char *msg_momnoexec2;
+extern char *msg_momjoboverlimit;
 extern char *msg_obitnojob;
 extern char *msg_obitnocpy;
 extern char *msg_obitnodel;
@@ -736,9 +737,7 @@ void on_job_exit(
   {
   int    handle = -1;
   job   *pjob;
-#ifdef VNODETESTING
   job   *pj;
-#endif
 
   struct batch_request *preq;
 
@@ -767,9 +766,7 @@ void on_job_exit(
     pjob = (job *)preq->rq_extra;
     }
 
-#ifdef VNODETESTING
-  /* FIXME: there might be a race with calling on_job_exit after a job has
-   * already been free'd.  This is temp code */
+  /* make sure the job is actually still there */
 
   pj = (job *)GET_NEXT(svr_alljobs);
 
@@ -781,29 +778,24 @@ void on_job_exit(
     pj = (job *)GET_NEXT(pj->ji_alljobs);
     }
 
+  /* if the job doesn't exist, just exit */
   if (pj == NULL)
     {
-    sprintf(log_buffer, "on_job_exit called with INVALID pjob: %p",
-            pjob);
+    sprintf(log_buffer, "on_job_exit called with INVALID pjob: %p",(void *)pjob);
+  
+    log_event(PBSEVENT_JOB,PBS_EVENTCLASS_JOB,"NULL",log_buffer);
+
+    return;
     }
   else
     {
     sprintf(log_buffer, "on_job_exit valid pjob: %p (substate=%d)",
-            pjob,
-            pjob->ji_qs.ji_substate);
+      (void *)pjob,
+      pjob->ji_qs.ji_substate);
+    
+    log_event(PBSEVENT_JOB,PBS_EVENTCLASS_JOB,"NULL",log_buffer);
     }
 
-  log_event(
-
-    PBSEVENT_JOB,
-    PBS_EVENTCLASS_JOB,
-    pjob->ji_qs.ji_jobid,
-    log_buffer);
-
-  DBPRT(("%s\n",
-         log_buffer));
-#endif /* END VNODETESTING */
-
   /*
    * we don't need a handle if we are complete. On starting up we will NOT have
    * a connection to mom, but still want to try and process the completed job
@@ -2464,6 +2456,12 @@ void req_jobobit(
     switch (exitstatus)
       {
 
+        /* the job exceeded some resource limit such as walltime, mem, pmem, cput, etc */
+        svr_mailowner(pjob, MAIL_ABORT, MAIL_FORCE, msg_momjoboverlimit);
+        alreadymailed = 1;
+
+        break;
+
       case JOB_EXEC_FAIL1:
 
       default:
