@@ -1739,7 +1739,7 @@ int svr_chkque(
 
         pas = pque->qu_attr[QA_ATR_AclGroup].at_val.at_arst;
 
-        for (i = 0;i < pas->as_usedptr;i++)
+        for (i = 0; pas != NULL && i < pas->as_usedptr;i++)
           {
           if ((grp = getgrnam(pas->as_string[i])) == NULL)
             continue;
@@ -1960,6 +1960,19 @@ int svr_chkque(
 
       return(i);
       }
+    else
+      {
+      if (strcmp(pque->qu_attr->at_val.at_str, "Execution") == 0)
+        {
+        /* job routed to Execution queue successfully */
+        /* unset job's procct resource */
+        resource_def *pctdef;
+        resource *pctresc;
+        pctdef = find_resc_def(svr_resc_def, "procct", svr_resc_size);
+        if ((pctresc = find_resc_entry(&pjob->ji_wattr[JOB_ATR_resource], pctdef)) != NULL)
+           pctdef->rs_free(&pctresc->rs_value);
+        }
+      }
     }    /* END if (mtype != MOVE_TYPE_MgrMv) */
 
   /* SUCCESS - job can enter queue */
@@ -2213,6 +2226,7 @@ char *prefix_std_file(
 
     if (name)
       {
+      memset(name, 0, len);
       strcpy(name, qsubhost); /* the qsub host name */
       strcat(name, ":");        /* the :  */
 
@@ -2379,11 +2393,14 @@ void set_resc_deflt(
   attribute *ji_wattr) /* I (optional) decoded attributes  */
 
   {
-  attribute *ja;
+  resource_def  *pctdef;
+  resource      *pctresc;
+  attribute     *ja;
 
-  pbs_queue *pque;
+  pbs_queue     *pque;
   attribute_def *pdef;
-  int i, rc;
+  int            i;
+  int            rc;
 
   pque = pjob->ji_qhdr;
 
@@ -2429,6 +2446,12 @@ void set_resc_deflt(
         }
       }
     }
+  
+  /* unset the procct resource if it has been set */
+  pctdef = find_resc_def(svr_resc_def, "procct", svr_resc_size);
+
+  if ((pctresc = find_resc_entry(ja, pctdef)) != NULL)
+    pctdef->rs_free(&pctresc->rs_value);
 
   return;
   }  /* END set_resc_deflt() */
